@@ -55,10 +55,16 @@ conf.registerChannelValue(Web, 'snarferReportIOExceptions',
 conf.registerChannelValue(Web, 'snarferShowDomain',
     registry.Boolean(True, _("""Determines whether domain names should be
     displayed by the title snarfer.""")))
+conf.registerChannelValue(Web, 'snarfMultipleUrls',
+    registry.Boolean(False, _("""Determines whether the title snarfer will
+    query all URLs in a message, or only the first one.""")))
 conf.registerChannelValue(Web, 'snarferShowTargetDomain',
     registry.Boolean(False, _("""Determines whether the domain name displayed
     by the snarfer will be the original one (posted on IRC) or the target one
     (got after following redirects, if any).""")))
+conf.registerChannelValue(Web, 'snarferPrefix',
+    registry.String(_('Title: '), _("""Determines the string used at before
+    a web page's title.""")))
 conf.registerChannelValue(Web, 'nonSnarfingRegexp',
     registry.Regexp(None, _("""Determines what URLs matching the given regexp
     will not be snarfed.  Give the empty string if you have no URLs that you'd
