@@ -34,6 +34,7 @@ Simple utility functions related to strings.
 """
 
 import re
+import sys
 import time
 import string
 import textwrap
@@ -305,6 +306,46 @@ def perlVariableSubstitute(vars, text):
                 return '$' + unbraced
     return _perlVarSubstituteRe.sub(replacer, text)
 
+def splitBytes(word, size):
+    # I'm going to hell for this function
+    for i in range(4): # a character takes at most 4 bytes in UTF-8
+        try:
+            if sys.version_info[0] >= 3:
+                word[size-i:].decode()
+            else:
+                word[size-i:].encode('utf8')
+        except UnicodeDecodeError:
+            continue
+        else:
+            return (word[0:size-i], word[size-i:])
+    assert False, (word, size)
+
+def byteTextWrap(text, size, break_on_hyphens=False):
+    """Similar to textwrap.wrap(), but considers the size of strings (in bytes)
+    instead of their length (in characters)."""
+    try:
+        words = textwrap.TextWrapper()._split_chunks(text)
+    except AttributeError: # Python 2
+        words = textwrap.TextWrapper()._split(text)
+    words.reverse() # use it as a stack
+    if sys.version_info[0] >= 3:
+        words = [w.encode() for w in words]
+    lines = [b'']
+    while words:
+        word = words.pop(-1)
+        if len(word) > size:
+            (before, after) = splitBytes(word, size)
+            words.append(after)
+            word = before
+        if len(lines[-1]) + len(word) <= size:
+            lines[-1] += word
+        else:
+            lines.append(word)
+    if sys.version_info[0] >= 3:
+        return [l.decode() for l in lines]
+    else:
+        return lines
+
 def commaAndify(seq, comma=',', And=None):
     """Given a a sequence, returns an English clause for that sequence.
 
